@@ -15,6 +15,18 @@ macro_rules! bind_partial_filler {
         }
     };
 }
+
+#[macro_export]
+macro_rules! bind_partial_filler_boxed {
+    ($name:ident, $field:ident, $type:ident) => {
+        fn $name(self, $field: Box<dyn $type>) -> Self {
+            let $field = Some($field);
+
+            Self { $field, ..self }
+        }
+    };
+}
+
 #[macro_export]
 macro_rules! bind_partial_filler_default {
     ($name:ident, $field:ident) => {
@@ -28,3 +40,12 @@ macro_rules! bind_partial_filler_default {
         }
     };
 }
+
+#[macro_export]
+macro_rules! bind_partial_trait_filler {
+    ($name:ident, $type:ident, $method:ident) => {
+        pub fn $name(self) -> Self {
+            self.$method(Box::new($type))
+        }
+    };
+}
