@@ -5,7 +5,7 @@ use std::fmt::Debug;
 use serde::{Deserialize, Serialize};
 
 #[cfg_attr(feature = "serde_support", typetag::serde(tag = "type"))]
-pub trait Period: Debug {
+pub trait Period: Debug + Send {
     fn contains(&self, date: Date<Utc>) -> bool;
     fn get_date_time_start(&self) -> DateTime<Utc>;
     fn starts_before(&self, date: Date<Utc>) -> bool;
